<?php
/**
 * 2011-2020 DMConcept
 *
 *  @author    DMConcept <support@dmconcept.fr>
 *  @copyright 2020 DMConcept
 *   @license   Commercial
 */



require_once ABSPATH . 'wp-content/plugins/Antsroute/classes/AntsRouteLogs.php';
require_once ABSPATH . 'wp-content/plugins/Antsroute/incl/config.php';

if (!class_exists('AntsRouteApiConnection')) {
    class AntsRouteApiConnection {
        private $token = '';
        private static $instance;

        private function __construct()
        {
            $this->token = get_option( 'antsroute_api_key');
        }

        public static function getInstance()
        {
            if (!isset(self::$instance)) {
                self::$instance = new AntsRouteApiConnection();
            }
            return self::$instance;
        }

        public function send($url, $method, $postData = array(), $contentType = 'application/json')
        {
            try {
                $fullUrl = ANTSROUTE_API_URL.$url;
                $dateSend = date("Y-m-d H:i:s");

                $postData = is_string($postData) ? $postData : json_encode($postData);

                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $fullUrl);
                curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: '.$contentType, 'cakey:  '.$this->token));

                if ($method == 'POST') {
                    curl_setopt($ch, CURLOPT_POST, true);
                    curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
                } elseif ($method == 'DELETE') {
                    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');
                    curl_setopt($ch, CURLOPT_URL, $fullUrl);
                } elseif ($method == 'PUT') {
                    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
                    curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
                }
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                $postResult = curl_exec($ch);


                if (curl_errno($ch)) {

                }

                $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);

                curl_close($ch);

                $dateReceive = date("Y-m-d H:i:s");

                $log = new AntsRouteLogs();
                $log->add(array(
                    'date_send'     => $dateSend,
                    'date_receive'  => $dateReceive,
                    'response_data' => $postResult,
                    'url'           => $fullUrl,
                    'method'        => $method,
                    'params'        => $postData,
                    'http_code'     => $http_code
                ));

                return array(
                    'data' => json_decode($postResult, true),
                    'status' => $http_code
                );
            } catch (Exception $e) {
                return false;
            }
        }
    }
}
