<?php
/**
 *  2011-2020 DMConcept
 *
 *  @author    DMConcept <support@dmconcept.fr>
 *  @copyright 2020 DMConcept
 *  @license   Commercial
 */



require_once ABSPATH . 'wp-content/plugins/Antsroute/classes/AntsRouteApiConnection.php';

if (!class_exists('AntsRouteManager')) {
    class AntsRouteManager {
        private static $instance;
        
        private  $weekTimeSlot;
        private  $chargingTimeSlots;
        
        
        const INTERVENTION_BASKET = 1;
        const MODULE_ORGANIZE = 2;

        private function __construct()
	        {
		    $this->weekTimeSlot = $this->generateWeekTimeSlot();
		    $this->chargingTimeSlots = 	$this->generatechargingTimeSlots();    
		    
		    
		    
	        }


		protected function generateWeekTimeSlot()
			{
			$arr_timeslots = array();	
				
			$arrDays = array('sunday' => 0,
							 'monday' => 1,
							 'tuesday' => 2,
							 'wednesday' => 3,
							 'thursday' => 4,
							 'friday' => 5,
							 'saturday' => 6
							 );
			
			foreach($arrDays as $day => $dayId)	
				{
				$arr_timeslots[$dayId] = array('enable' => get_option( 'antsroute_'.$day.'_delivery_status'),
											   'start' => get_option( 'antsroute_'.$day.'_delivery_start'), 
								    		   'end' => get_option( 'antsroute_'.$day.'_delivery_end'));							
				}
				
			return $arr_timeslots;
			}
			
		protected function generatechargingTimeSlots()
			{
			return array('start' => get_option( 'antsroute_loading_time_start'), 'end' => get_option( 'antsroute_loading_time_end'));	
			}
			
						
        public function getExternalId($idOrder)
        {
            return substr((string)get_option( 'antsroute_api_key'), 0, 10) . '-' . $idOrder;
        }

        // @return AntsRouteManager

        public static function getInstance()
        {
            if (!isset(self::$instance)) {
                self::$instance = new AntsRouteManager();
            }
            return self::$instance;
        }

        // @return bool|false|string
        protected function selectDueDate($offset = '')
        	{	      
	        $deliveryWeekTimeSlots =  $this->weekTimeSlot;	

			// check for invalid timeSlot
            $hasValidDate = false;
            
            foreach ($deliveryWeekTimeSlots as $timeSlot) {
                if (!empty($timeSlot['start']) && !empty($timeSlot['end'])) {
                    $hasValidDate = true;
                }
            }
            if (!$hasValidDate) {
                return false;
            }


			// calculate dueDate

	        	
	        $min_offset = (int)get_option( 'antsroute_delivery_deadline');
	        $offset	= 1;
	        	 
	        do
	        	{ 
				$dueDate = date('Y-m-d', strtotime("+$offset days"));	
				$dueDateDayNumber = date('w', strtotime($dueDate));
				
                $timeSlot = $deliveryWeekTimeSlots[$dueDateDayNumber];
                
                if ($timeSlot['enable'] == 'no' ) 
                	{
					$min_offset++;
				echo " -> fermé -> + 1J / min_offset = $min_offset / offset = $offset";
	                	
                	}
		        else
		        	{
			        if ($offset >= $min_offset)
			        	{
				        return $dueDate;	
			        	}				        	
		        	}

		        	
		        $offset++;	
	        	}	
	        	while($offset <= $min_offset);
	        		
			

        	}


         // @param $orderDetail
         
         // @return bool|mixed
         // @throws PrestaShopDatabaseException
         //  @throws PrestaShopException
        public function triggerDelivery($orderDetail)
        {
            // get config variables
        
            $delivery_method = get_option( 'antsroute_carrier');

            if ($delivery_method != $orderDetail['shipping'])
            	return array('data' => array('errorCode' => '666', 
            								 'message' => __('Delivery Method')));

            $deliveryWeekTimeSlots =  $this->weekTimeSlot;
            $duration = (int)get_option( 'antsroute_delivery_time');
  
             // set request data
            $dueDate = $this->selectDueDate();

            $dueDateDayNumber = date('w', strtotime($dueDate));

    		$phoneNumber = '';
            $mobileNumber = '';
     
            if (trim($orderDetail['customer']['phone']) != '')
            	{
	            if (stripos(trim($orderDetail['customer']['phone']), '+') !== false)	
	            	$mobileNumber = trim($orderDetail['customer']['phone']);
	            else
	            	$phoneNumber = trim($orderDetail['customer']['phone']);	            
            	}
            
            $address = $orderDetail['customer']['address_1'] . ' ' .  $orderDetail['customer']['address_2'] . ' ' . $orderDetail['customer']['postcode'] . ' ' . $orderDetail['customer']['city'];
            $customer = array(
                'lastName'   => $orderDetail['customer']['first_name'],
                'firstName'  => $orderDetail['customer']['last_name'],
                'address'    => $address,
                'externalId' => $this->getExternalId($orderDetail['customer']['wcId']),
                'email'      => $orderDetail['customer']['email'],
                'phoneNumber' => $phoneNumber,
                'mobileNumber' => $mobileNumber,	
            );
            

         
            $type = (int)get_option( 'antsroute_enable_pickup') ? 'DELIVERY' : 'SERVICE'; // SERVICE|DELIVERY|COLLECT

            $comments = $orderDetail['comments'];

            $weight = 0;
            $numberOfProduct = 0;
            $description = '';
            foreach ($orderDetail['products'] as $key => $product) {
	            
	            if (trim($product['weight']) == '')
	            	$product['weight'] = 0;
	            	
                $description .= $product['sku'] . " ";
                $weight += $product['weight'];
                $numberOfProduct += $product['quantity'];
            }
            $customFields = array(
                array('name' => 'Description', 'value' => empty($description) ? $description : str_replace(" ", " - ", substr($description, 0, strlen($description) - 1))),
                array('name' => 'Price', 'value' => $orderDetail['info']['price_total']),
                array('name' => 'Reference', 'value' => 19)
            );

            $capacities = array(
                array('capacityName' => 'Number', 'capacityValue' => $numberOfProduct),
                array('capacityName' => 'Weight', 'capacityValue' => $weight),
            );
 
 
            $url = (int)get_option( 'antsroute_add_in_order') === self::INTERVENTION_BASKET ? 'capi/order/basket' : 'capi/order/planning';

            $data = array(
                'dueDate'      => $dueDate,
                'scheduleDate' => $dueDate,
                'type'         => $type,
                'duration'     => $duration,
                'externalId'   => $this->getExternalId($orderDetail['info']['idOrder']),
                'timeSlot'     => $deliveryWeekTimeSlots[$dueDateDayNumber],
                'customer'     => $customer,
                'comments'     => $comments ? $comments : "",
                'customFields' => $customFields,
                'capacities'   => $capacities,
            );
            
            if ((int)get_option( 'antsroute_enable_pickup') ) {
                $data['loading'] = array(
                    'location' => array(
                        'name'    =>  get_option( 'antsroute_deposit_name'),
                        'address' => get_option( 'antsroute_deposit_address')
                    ),
                    'duration' => (int)get_option( 'antsroute_loading_time'),
                    'timeSlot' => $this->chargingTimeSlots,
                );
            }

            if (!$dueDate) return false;
         
            return AntsRouteApiConnection::getInstance()->send($url, 'POST', $data, 'application/json');

        }

         // @param $idOrder
         // @return bool|mixed
        public function triggerCancel($idOrder)
        {
            return AntsRouteApiConnection::getInstance()->send('capi/order/external-id/' . $this->getExternalId($idOrder) . '?purge=true', 'DELETE');
        }


         // @param $idOrder
         // @return bool|string
        public function getAntsRouteOrderInfo($idOrder)
        {
	        	        
            $antsRouteOrder =  AntsRouteApiConnection::getInstance()->send('capi/order/external-id/' . $this->getExternalId($idOrder), 'GET');

            if ($antsRouteOrder && substr($antsRouteOrder['status'],0, 1) == 2) 
            	{
                return array('dueDate' => $antsRouteOrder['data']['dueDate'],
			                 'scheduledDate' => $antsRouteOrder['data']['scheduledDate'],
			                 'state' => $antsRouteOrder['data']['state']);
				}
            else
            	{
                return array('dueDate' => '',
			                 'scheduledDate' => '',
			                 'state' => $antsRouteOrder['status']);
				}
				            
            return false;
        }
           
    }
    
 
}

