<?php

	require_once ABSPATH . 'wp-content/plugins/Antsroute/classes/AntsRouteManager.php';	

	
	/*	
	*/
	
	/**
	 * Add a custom action when status changed	
	 *
	 * @param $this_get_id ->  The order id.
	 * @param this_status_transition_from ->  The order status transition from.
	 * @param this_status_transition_to ->  The order status transition to.
	 * @param instance ->  The order.
	 
	 * @return 
	 */	
	
	// define the woocommerce_order_status_changed callback 
	function action_woocommerce_order_status_changed( $this_get_id, $this_status_transition_from, $this_status_transition_to, $instance ) 
		{ 
		$antsroute_cancel_trigger = get_option( 'antsroute_cancel_trigger');
	    $antsroute_delivery_trigger = get_option( 'antsroute_delivery_trigger');			
	    
		switch('wc-'.$this_status_transition_to)
			{
			case $antsroute_cancel_trigger:
				
				AntsRouteManager::getInstance()->triggerCancel($this_get_id);
				
				update_post_meta( $this_get_id,'antsroute_delivery_date',''); // remove delivery date from order
				update_post_meta( $this_get_id,'antsroute_state', $antsrute_order_info['state']); // update delivery date from order	
				
			    // add the order note
			    $message =  __( 'Order canceled in  AntsRoute.', 'ants-route' );
			    $instance->add_order_note( $message );				
			
				break;
			
			case $antsroute_delivery_trigger;

				// get usefull order data	
				$arr_products = array();
				
				foreach ( $instance->get_items() as $item_id => $item ) 
					{
					$product = $item->get_product();
					
					array_push($arr_products, array('product_id' => $item->get_product_id(),
												    'variation_id' => $item->get_variation_id(),
												    'name' => $item->get_name(),
												    'quantity' => $item->get_quantity(),
												    'subtotal' => $item->get_subtotal(),
												    'total' => $item->get_total(),
												    'tax' => $item->get_subtotal_tax(),
												    'taxclass' => $item->get_tax_class(),
												    'taxstat' => $item->get_tax_status(),
												    'weight' => $product->get_weight(),
												    'sku' => $product->get_sku(),
												   ));
		
					}
		
				$orderDetail = array('customer' => $instance->get_address('shipping'),
									 'comments' => $instance->get_customer_note(),
									 'products' => $arr_products,		
									 'shipping' => $instance->get_shipping_method(),
									 'info' => array('idOrder' => $instance->get_id(),
									 				 'price_total' => $instance->get_order_number()));
		
				$orderDetail['customer']['wcId'] = $instance->get_customer_id();
				$orderDetail['customer']['email'] = $instance->get_billing_email();
				$orderDetail['customer']['phone'] = $instance->get_billing_phone();
								
				$added = AntsRouteManager::getInstance()->triggerDelivery($orderDetail);
				
				$deliveryDate = '';
				
		        if ($added && is_null($added['data']['errorCode'])) 
		        	{
			        $deliveryDate = empty($added['data']['scheduledDate']) ? $added['data']['dueDate'] : $added['data']['scheduledDate'];

				    update_post_meta( $instance->get_id(),'antsroute_delivery_date', $deliveryDate); // update delivery date from order
				    
				    // add the order note
					$message = sprintf( __( 'Order sent  to  AntsRoute (delivery date: %s)', 'ants-route') , $deliveryDate);            

				    $instance->add_order_note( $message );			            
		        	}
				else if (is_array($added))
					{	
				    // add the order note
				    $message = __( "Failed to sent back to  AntsRoute, please check logs", 'ants-route' ) . " -> " . $added['data']['message'];
				    $instance->add_order_note( $message );					   		            					
					}		    
					
			
				break;	
			}
	

	
		}; 
	         
	// add the action 
	add_action( 'woocommerce_order_status_changed', 'action_woocommerce_order_status_changed', 10, 4 ); 	
		
		
	

	/**
	 * Add a custom action to order actions select box on edit order page
	 * Only added for paid orders that haven't fired this action yet
	 *
	 * @param array $actions order actions array to display
	 * @return array - updated actions
	 */
	 
	
	function wc_add_order_meta_box_action( $actions ) 
		{
	    global $theorder;

	    $order_data = $theorder->get_data();
	    
	    $order_status = 'wc-'.$order_data['status'];
	    
	    $antsroute_cancel_trigger = get_option( 'antsroute_cancel_trigger');
	    $antsroute_delivery_trigger = get_option( 'antsroute_delivery_trigger');
	    
	    // check antsroute order info to update orderpage data
		if ( $order_status == $antsroute_delivery_trigger  ) 
	    	{
	    	$antsrute_order_info = AntsRouteManager::getInstance()->getAntsRouteOrderInfo($theorder->get_id());
	    	
			if (isset($antsrute_order_info['dueDate']) || isset($antsrute_order_info['scheduledDate']))
				{
				if ($antsrute_order_info['state'] == '404')
					{
					update_post_meta( $theorder->get_id(),'antsroute_delivery_date', ''); // update delivery date from order	
					update_post_meta( $theorder->get_id(),'antsroute_state', ''); // update delivery date from order						
					}
				else
					{
					$deliveryDate = empty($antsrute_order_info['scheduledDate']) ? $antsrute_order_info['dueDate'] : $antsrute_order_info['scheduledDate'];
	
					update_post_meta( $theorder->get_id(),'antsroute_delivery_date', $deliveryDate); // update delivery date from order	
					update_post_meta( $theorder->get_id(),'antsroute_state', $antsrute_order_info['state']); // update delivery date from order							
					}
				}	   
			}

	
	    // if the order has been paid for or this action has been run
	    if ( ! ( $order_status == $antsroute_cancel_trigger || $order_status == $antsroute_delivery_trigger ) ) 
	    	{
	        return $actions;
	    	}

	
	    // add custom action
	    $actions['wc_custom_order_antsroute_action'] = __( 'Send back order to AntsRoute', 'ants-route' );
	    
	    return $actions;
		}
	
	add_action( 'woocommerce_order_actions', 'wc_add_order_meta_box_action' );
	
	
	
	
	
	/**
	 * send back order to antsroute when order page action is triggered	 
	 *
	 * @param \WC_Order $order
	 */
	function wc_process_order_meta_box_antsroute_action( $order )
		{
		$antsroute_cancel_trigger = get_option( 'antsroute_cancel_trigger');
	    $antsroute_delivery_trigger = get_option( 'antsroute_delivery_trigger');
	    
		switch('wc-'.$order->get_status())
			{
			case $antsroute_cancel_trigger:
				
				AntsRouteManager::getInstance()->triggerCancel($order->get_id());
				
				update_post_meta( $order->get_id(),'antsroute_delivery_date',''); // remove delivery date from order
				update_post_meta( $order->get_id(),'antsroute_state',''); // remove delivery state from order
				
			    // add the order note
			    $message =  __( 'Order canceled again in  AntsRoute.', 'ants-route' );
			    $order->add_order_note( $message );				
			
				break;
			
			case $antsroute_delivery_trigger;
			
				// get usefull order data	
				$arr_products = array();
				
				foreach ( $order->get_items() as $item_id => $item ) 
					{
					$product = $item->get_product();
					
					array_push($arr_products, array('product_id' => $item->get_product_id(),
												    'variation_id' => $item->get_variation_id(),
												    'name' => $item->get_name(),
												    'quantity' => $item->get_quantity(),
												    'subtotal' => $item->get_subtotal(),
												    'total' => $item->get_total(),
												    'tax' => $item->get_subtotal_tax(),
												    'taxclass' => $item->get_tax_class(),
												    'taxstat' => $item->get_tax_status(),
												    'weight' => $product->get_weight(),
												    'sku' => $product->get_sku(),
												   ));
		
					}
		
				$orderDetail = array('customer' => $order->get_address('shipping'),
									 'comments' => $order->get_customer_note(),
									 'products' => $arr_products,
									 'shipping' => $order->get_shipping_method(),									 								 
									 'info' => array('idOrder' => $order->get_id(),
									 'price_total' => $order->get_order_number()));
		
				$orderDetail['customer']['wcId'] = $order->get_customer_id();
				$orderDetail['customer']['email'] = $order->get_billing_email();
				$orderDetail['customer']['phone'] = $order->get_billing_phone();

				$added = AntsRouteManager::getInstance()->triggerDelivery($orderDetail);		

				$deliveryDate = '';
				
		        if ($added && is_null($added['data']['errorCode'])) 
		        	{
			        $deliveryDate = empty($added['data']['scheduledDate']) ? $added['data']['dueDate'] : $added['data']['scheduledDate'];
		            
				    update_post_meta( $order->get_id(),'antsroute_delivery_date', $deliveryDate); // update delivery date from order
				    				    
				    $message = sprintf( __( 'Order sent back to  AntsRoute (delivery date: %s)', 'ants-route') , $deliveryDate);            
				    $order->add_order_note( $message );					   		            
		        	}
				else if (is_array($added))
					{	
				    // add the order note
				    $message = __( "Failed to sent back to AntsRoute, please check logs", 'ants-route' ) . " -> " . $added['data']['message'];
				    $order->add_order_note( $message );					   		            					
					}
 
				break;	
			}			

		}
	
	add_action( 'woocommerce_order_action_wc_custom_order_antsroute_action', 'wc_process_order_meta_box_antsroute_action' );	
?>